@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2007 Loic Dachary <loic@dachary.org>
+# Copyright (C) 2007, 2008 Loic Dachary <loic@dachary.org>
 # Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
@@ -9,7 +9,7 @@
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -59,10 +59,10 @@ meaning that the card is unknown.
     def best(self, side, hand, board = []):
         """\
 Return the best five card combination that can be made with the cards
-listed in "hand" and, optionaly, board. The "side" may be "hi" or
-"low". The "board" argument need only be provided for variants where
+listed in "hand" and, optionally, board. The "side" may be "hi" or
+"low". The "board" argument must only be provided for variants where
 knowing if a given card is taken from the board or not is significant
-(such as Omaha).
+(such as Omaha but not Holdem).
 
 A list is returned. The first element is the numerical value
 of the hand (better hands have higher values if "side" is "hi" and
@@ -139,9 +139,16 @@ won the low side.
 See the"poker_eval" method for a detailed
 explanation of the semantics of the arguments.
 
-If the keyword argument "fill_pockets" is set, remove any pocket
-hand that contains a place holder (i.e. 255 or __) or any empty
-pocket (i.e. []).
+If the keyword argument "fill_pockets" is set, pocket cards
+can contain a placeholder (i.e. 255 or __) that will be be
+used as specified in the "poker_eval" method documentation.
+
+If the keyword argument "fill_pockets" is not set, pocket cards
+that contain at least one placeholder (i.e. 255 or __) are
+ignored completly. For instance if winners is called as follows
+o.winners(game = 'holdem', pockets = [ [ '__', 'As' ], [ 'Ks', 'Kd'] ])
+it is strictly equivalent as calling
+o.winners(game = 'holdem', pockets = [ [ 'Ks', 'Kd'] ]).
 """
         index2index = {}
         normalized_pockets = []
@@ -191,6 +198,12 @@ pockets   : list of pocket cards for each player still in game. Each member
             in the list is meaningfull for the value returned will refer to
             this position when stating which player wins, tie or loose.
             Example: [ ["tc", "ac"],  ["3h", "ah"],  ["8c", "6h"]]
+            Cards do not have to be real cards like "tc" or "4s". They may also be a 
+            placeholder, denoted by "__" or 255. When using placeholders, the 
+            keyword argument "iterations" may be specified to use Monte Carlo instead of
+            exhaustive exploration of all the possible combinations.
+            Example2: [ ["tc", "__"],  [255, "ah"],  ["8c", "6h"]]
+
             Mandatory, no default.
 
 board     : list of community cards, for games where this is meaningfull. If
